@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.012-3-g3af8b69
+package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.013-3-g7e4034d
 # ABSTRACT: Perform arbitrary commands when Dist::Zilla prompts you
 # KEYWORDS: prompt execute command external
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 with 'Dist::Zilla::Role::Plugin';
@@ -52,9 +52,9 @@ around register_component => sub
 __PACKAGE__->meta->make_immutable;
 
 
-package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.012-3-g3af8b69
+package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.013-3-g7e4034d
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose::Role;
 use IPC::Open3;
@@ -99,9 +99,9 @@ around [qw(prompt_str prompt_yn)] => sub {
     my $done = waitpid($pid, WNOHANG);
 
     my $exit_status = $? >> 8;
-    warn "[Chrome::ExtraPrompt] process exited with status $exit_status\n" if $done and $exit_status;
+    warn "[Chrome::ExtraPrompt] process exited with status $exit_status\n" if $done == $pid and $exit_status;
 
-    my $ret = kill 'KILL', $pid;
+    kill 'KILL', $pid if $done == 0;
 
     foreach my $warning (<$err>)
     {
@@ -125,7 +125,7 @@ Dist::Zilla::Plugin::Chrome::ExtraPrompt - Perform arbitrary commands when Dist:
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -157,6 +157,13 @@ A boolean flag (defaulting to false) that, when set,
 appends the prompt string to the command and arguments that are called,
 passing as a single (additional?) argument.
 
+=head1 CAVEATS
+
+Some architectures may be incapable of processing the kill signal sent to the
+command when the prompt returns; if this is happening to you, let me know and I
+can do some more things in code to avoid this (such as massaging the command to
+avoid a shell intermediary).
+
 =head1 SUPPORT
 
 =for stopwords irc
